<?php

namespace Countee\Components\Account;

use Nette;
use Nette\Application\UI\Form;
use Countee;

class Fio extends General
{

    /**
     * @var Countee\Model\Bank\Fio
     */
    private $fioAccount;
    private $userId;
    private $account;

    public function __construct(Countee\Model\Bank\Fio\Account $fioAccount, int $userId, $accountId = null)
    {
        parent::__construct();

        $this->fioAccount = $fioAccount;
        $this->userId = $userId;

        if (!empty($accountId)) {
            $this->account = $fioAccount->getAccount($accountId, $userId);
        }
    }

    protected function createComponentAccountForm()
    {
        $form = new Form;

        Countee\Helper\Form::makeBootstrap3($form);

        $form->addText('account_name', 'Název účtu:')
                ->setRequired('Zadejte název účtu.');
        $form->addTextArea('account_description', 'Popisek:');
        $form->addText('fio_token', 'Fio API token:')
                ->setRequired('Není vložen token');
        $form->addSubmit('send', 'Submit');

        if (!empty($this->account)) {
            $form->setDefaults([
                'account_name' => $this->account->account_name,
                'account_description' => $this->account->account_description,
                'fio_token' => $this->fioAccount->getAccountMeta('fio_token', $this->account->id)
            ]);
            $form->onSuccess[] = [$this, 'formEditSuccess'];
        } else {
            $form->onSuccess[] = [$this, 'formSuccess'];
        }


        return $form;
    }

    public function handleDelete()
    {
        if ($this->account) {
            $this->account->delete();
        }
    }

    public function formEditSuccess(Form $form)
    {
        $values = $form->getValues();
        $editAccount = $this->fioAccount->editAccount($this->account->id, $this->userId, $values->account_name, $values->account_description, $values->fio_token);

        $this->presenter->flashMessage('Účet ' . $values->account_name . ' byl aktualizován.', 'success');
        $this->presenter->redirect('this');
    }

    public function formSuccess(Form $form)
    {
        $values = $form->getValues();

        $account = $this->fioAccount->createAccount($this->userId, $values->account_name, $values->account_description, $values->fio_token);
        if ($account) {
            $this->presenter->flashMessage('Účet ' . $values->account_name . ' byl vytvořen.', 'success');
            $this->presenter->redirect('Transaction:default', ['accountId' => $account->id]);
        } else {
            $this->presenter->flashMessage('Účet ' . $values->account_name . ' se nepodařilo vytvořit. Špatně zadaný token?', 'danger');
            $this->presenter->redirect('this');
            
        }
    }

    public function render()
    {
        $this->template->account = $this->account;
        $this->template->render(__DIR__ . '/templates/Fio.latte');
    }

}
