<?php

namespace Countee\Components\Payable;

use Nette;
use Nette\Application\UI\Form;
use Countee;

class Commitment extends Nette\Application\UI\Control
{

    /**
     * @var Countee\Model\Payable\Commitment
     */
    private $commitmentModel;

    /**
     * @var Countee\Model\Category\Model
     */
    private $categoryModel;

    /**
     *
     * @var int
     */
    private $userId;
    private $commitment;

    public function __construct(Countee\Model\Payable\Commitment $commitmentModel, Countee\Model\Category\Model $categoryModel, int $userId, $commitmentId = null)
    {
        $this->commitmentModel = $commitmentModel;
        $this->categoryModel = $categoryModel;

        $this->userId = $userId;


        if (!empty($commitmentId)) {
            $this->commitment = $commitmentModel->getCommitment($commitmentId, $userId);
        }

        parent::__construct();
    }

    protected function createComponentCommitmentForm()
    {
        $form = new Form;

        Countee\Helper\Form::makeBootstrap3($form);

        $form->addText('name', 'Název');
        $form->addTextArea('description', 'Popis');
        $form->addSelect('account_id', 'Zaplatit z účtu', $this->categoryModel->getTable('account')->where(['user_id' => $this->userId])->fetchPairs('id', 'account_name'))
                ->setRequired('Vyberte účet, ze kterého bude závazek placen.');
        $form->addText('ammount', 'Částka k uhrazení')
                ->setRequired('Zadejte částku k uhrazení')
                ->addRule(Form::FLOAT, 'Hodnota musí být číslo.');
        $form->addText('due_date', 'Datum splatnosti');
        $form->addText('account_number', 'Číslo účtu')
                ->setAttribute('placeholder', '2001049665')
                ->setRequired('Není zadáno číslo účtu')
                ->addRule(Countee\Helper\Form::BANK_ACCOUNT, 'Číslo účtu je zadáno nesprávně.');
        $form->addText('account_bank', 'Kód banky')
                ->setAttribute('placeholder', '2010')
                ->setRequired('Není zadán kod banky');
        $form->addText('vs', 'Variabilní symbol');
        $form->addText('ks', 'Kontaktní symbol');
        $form->addText('ss', 'Specifický symbol');
        $form->addText('message', 'Zpráva pro příjemce');
        $form->addSubmit('send', 'Uložit');

        $form->onValidate[] = [$this, 'validateForm'];

        if ($this->commitment) {
            $form->setDefaults($this->commitment);
            $form['due_date']->setDefaultValue($this->commitment->due_date->format('d. m. Y.'));
            $form->onSuccess[] = [$this, 'formSuccessEdit'];
            
            if($this->commitment->paid >= $this->commitment->ammount) {
                foreach ($form->getComponents() as $item) {
                    if(!in_array($item->getName(), ['name', 'description', 'send'])) {
                        $item->setDisabled(true);
                    }
                }
            }
        } else {
            $form->onSuccess[] = [$this, 'formSuccess'];
        }

        return $form;
    }

    public function formSuccess(Form $form)
    {
        $this->commitmentModel->createCommitment($this->userId, $form->getValues());
        $this->presenter->flashMessage('Závazek ' . $form->getValues()->name . ' byl přidán.', 'success');
    
        $this->presenter->redirect('this');
    }
    
    public function formSuccessEdit(Form $form)
    {
        $this->commitmentModel->editCommitment($this->userId, $this->commitment->id, $form->getValues());
        $this->presenter->flashMessage('Závazek ' . $form->getValues()->name . ' byl upraven.', 'success');
    
        $this->presenter->redirect('this');
    }

    public function validateForm(Form $form)
    {
        if ($form->hasErrors()) {
            foreach ($form->errors as $error) {
                $this->presenter->flashMessage('Přidání závazku: ' . $error, 'danger');
            }
        }
    }

    public function render()
    {
        $this->template->commitment = $this->commitment;
        $this->template->render(__DIR__ . '/templates/Commitment.latte');
    }

}
