<?php

namespace Countee\Components\Payable;

use Nette;
use Nette\Application\UI\Form;
use Countee;
use Higi90;

class CommitmentInvoice extends Nette\Application\UI\Control
{

    /**
     * @var Countee\Model\Payable\Commitment
     */
    private $commitmentModel;

    /**
     * @var Countee\Model\Category\Model
     */
    private $categoryModel;

    /**
     *
     * @var int
     */
    private $userId;

    public function __construct(Countee\Model\Payable\Commitment $commitmentModel, Countee\Model\Category\Model $categoryModel, int $userId)
    {
        $this->commitmentModel = $commitmentModel;
        $this->categoryModel = $categoryModel;

        $this->userId = $userId;

        parent::__construct();
    }

    protected function createComponentCommitmentForm()
    {
        $form = new Form;

        Countee\Helper\Form::makeBootstrap3($form);

        $form->addText('name', 'Název');
        $form->addTextArea('description', 'Popis');
        $form->addSelect('account_id', 'Zaplatit z účtu', $this->categoryModel->getTable('account')->where(['user_id' => $this->userId])->fetchPairs('id', 'account_name'))
                ->setRequired('Vyberte účet, ze kterého bude závazek placen.');
        $form->addUpload('invoice', 'Soubor s fakturou')
                ->setRequired('Není vložen soubor s fakturou');
        $form->addSubmit('send', 'Uložit');

        $form->onValidate[] = [$this, 'validateForm'];

        $form->onSuccess[] = [$this, 'formSuccess'];

        return $form;
    }

    public function formSuccess(Form $form)
    {
        $values = $form->getValues();
        try {
            $this->commitmentModel->createCommitmentInvoice($this->userId, $values->invoice, $values->name, $values->description, $values->account_id);
            $this->presenter->flashMessage('Závazek ' . $form->getValues()->name . ' byl přidán.', 'success');
            $this->presenter->redirect('this');
            
        } catch (Higi90\SpaydParser\Exception\InvalidStringFormatException $ex) {
            $this->presenter->flashMessage('Nepodařilo se správně detekovat QR kód na vložené faktuře.', 'danger');
        }
    }

    public function validateForm(Form $form)
    {
        if ($form->hasErrors()) {
            foreach ($form->errors as $error) {
                $this->presenter->flashMessage('Přidání závazku: ' . $error, 'danger');
            }
        }
    }

    public function render()
    {
        $this->template->render(__DIR__ . '/templates/Commitment.latte');
    }

}
