<?php

namespace Countee\Components\Payable;

use Nette;
use Nette\Application\UI\Form;
use Countee;

class Receivable extends Nette\Application\UI\Control
{

    /**
     * @var Countee\Model\Payable\Receivable
     */
    private $receivableModel;

    /**
     * @var Countee\Model\Category\Model
     */
    private $categoryModel;

    /**
     *
     * @var int
     */
    private $userId;
    private $receivable;

    public function __construct(Countee\Model\Payable\Receivable $receivableModel, Countee\Model\Category\Model $categoryModel, int $userId, $receivableId = null)
    {
        $this->receivableModel = $receivableModel;
        $this->categoryModel = $categoryModel;

        $this->userId = $userId;


        if (!empty($receivableId)) {
            $this->receivable = $receivableModel->getReceivable($receivableId, $userId);
        }

        parent::__construct();
    }

    protected function createComponentReceivableForm()
    {
        $form = new Form;

        Countee\Helper\Form::makeBootstrap3($form);

        $form->addText('name', 'Název');
        $form->addTextArea('description', 'Popis');
        $form->addSelect('account_id', 'Připsat na účet', $this->categoryModel->getTable('account')->where(['user_id' => $this->userId])->fetchPairs('id', 'account_name'))
                ->setRequired('Vyberte účet, ze kterého bude závazek placen.');
        $form->addText('ammount', 'Částka k uhrazení')
                ->setRequired('Zadejte částku k uhrazení')
                ->addRule(Form::FLOAT, 'Hodnota musí být číslo.');
        $form->addText('due_date', 'Datum splatnosti');
        $form->addText('vs', 'Variabilní symbol');
        $form->addSubmit('send', 'Uložit');

        $form->onValidate[] = [$this, 'validateForm'];

        if ($this->receivable) {
            $form->setDefaults($this->receivable);
            $form['due_date']->setDefaultValue($this->receivable->due_date->format('d. m. Y.'));
            $form->onSuccess[] = [$this, 'formSuccessEdit'];
            
            if($this->receivable->paid > 0) {
                foreach ($form->getComponents() as $item) {
                    if(!in_array($item->getName(), ['name', 'description', 'send'])) {
                        $item->setDisabled(true);
                    }
                }
            }
        } else {
            $form->onSuccess[] = [$this, 'formSuccess'];
        }

        return $form;
    }

    public function formSuccess(Form $form)
    {
        $this->receivableModel->createReceivable($this->userId, $form->getValues());
        $this->presenter->flashMessage('Pohledávka ' . $form->getValues()->name . ' byla přidána.', 'success');
    
        $this->presenter->redirect('this');
    }
    
    public function formSuccessEdit(Form $form)
    {
        $this->receivableModel->editReceivable($this->userId, $this->receivable->id, $form->getValues());
        $this->presenter->flashMessage('Pohledávka ' . $form->getValues()->name . ' byla upravena.', 'success');
    
        $this->presenter->redirect('this');
    }

    public function validateForm(Form $form)
    {
        if ($form->hasErrors()) {
            foreach ($form->errors as $error) {
                $this->presenter->flashMessage('Přidání závazku: ' . $error, 'danger');
            }
        }
    }

    public function render()
    {
        $this->template->receivable = $this->receivable;
        $this->template->render(__DIR__ . '/templates/Receivable.latte');
    }

}
