<?php

namespace Countee\Helper;

use Nette;

class Form
{

    const BANK_ACCOUNT = 'Countee\Helper\Form::validateBankAccount';

    public static function makeBootstrap3(Nette\Application\UI\Form $form)
    {
        $renderer = $form->getRenderer();
        $renderer->wrappers['controls']['container'] = NULL;
        $renderer->wrappers['pair']['container'] = 'div class=form-group';
        $renderer->wrappers['pair']['.error'] = 'has-error';
        $renderer->wrappers['control']['container'] = 'div class=col-sm-9';
        $renderer->wrappers['label']['container'] = 'div class="col-sm-3 control-label"';
        $renderer->wrappers['control']['description'] = 'span class=help-block';
        $renderer->wrappers['control']['errorcontainer'] = 'span class=help-block';
        $form->getElementPrototype()->class('form-horizontal');
        $form->onRender[] = function ($form) {
            foreach ($form->getControls() as $control) {
                $type = $control->getOption('type');
                if ($type === 'button') {
                    $control->getControlPrototype()->addClass(empty($usedPrimary) ? 'btn btn-primary' : 'btn btn-default');
                    $usedPrimary = TRUE;
                } elseif (in_array($type, ['text', 'textarea', 'select'], TRUE)) {
                    $control->getControlPrototype()->addClass('form-control');
                } elseif (in_array($type, ['checkbox', 'radio'], TRUE)) {
                    $control->getSeparatorPrototype()->setName('div')->addClass($type);
                }
            }
        };
    }

    public static function validateBankAccount($bankAccount)
    {
        if (!preg_match('/(([0-9]{0,6})-)?([0-9]{1,10})$/', $bankAccount->value, $matches)) {
            return false;
        }
        $first = sprintf('%06d', $matches[1]);
        $second = sprintf('%010d', $matches[3]);

        $isOk = (10 * $first[0] + 5 * $first[1] + 8 * $first[2] + 4 * $first[3] + 2 * $first[4] + 1 * $first[5]) % 11 == 0;

        if ($isOk === false) {
            return false;
        }

        // SECOND PART - MODULO 11
        $isOk = ( 6 * $second[0] + 3 * $second[1] + 7 * $second[2] + 9 * $second[3] + 10 * $second[4] + 5 * $second[5] + 8 * $second[6] + 4 * $second[7] + 2 * $second[8] + 1 * $second[9]) % 11 == 0;

        if ($isOk == false) {
            return false;
        }

        return TRUE;
    }

}
