<?php

namespace Countee\Model\Bank\Fio;

use Countee;

class Transaction extends Countee\Model\Bank\Transaction
{
    const COLUMN_DATE = 'column0';
    const COLUMN_AMMOUNT = 'column1';
    const COLUMN_CURRENCY = 'column14';
    const COLUMN_TYPE = 'column8';
    const COLUMN_ID = 'column22';
    const COLUMN_VS = 'column5';
    const COLUMN_KS = 'column4';
    const COLUMN_RELATED_ACCOUNT_NUMBER = 'column2';
    const COLUMN_RELATED_BANK_CODE = 'column3';
    const COLUMN_MSG = 'column25';
    
    const TRANSACTION_REQUIRED_COLUMNS = ['column0', 'column1', 'column14', 'column8', 'column22'];

    /**
     * Validates transaction structure
     *
     * @param array $transactionArray
     * @return bool
    */
    protected function validateInput(array $transactionArray)
    {
        
        foreach (self::TRANSACTION_REQUIRED_COLUMNS as $requiredColumn) {
            if (!array_key_exists($requiredColumn, $transactionArray)) {
                throw new Countee\Model\Bank\Exception\InvalidStructureException('Transaction does not contains required columns.');
            }
        }

        return true;
    }

    /**
     * Parse input string
     *
     * @param array $transactionArray
     */
    protected function parseInput(array $transactionArray)
    {
        $this->id = static::getIndex(self::COLUMN_ID, $transactionArray, false);
        $this->date = new \Datetime(static::getIndex(self::COLUMN_DATE, $transactionArray, false));
        $this->ammount = static::getIndex(self::COLUMN_AMMOUNT, $transactionArray, false);
        $this->currency = static::getIndex(self::COLUMN_CURRENCY, $transactionArray, false);
        $this->type = static::getIndex(self::COLUMN_TYPE, $transactionArray, false);
        $this->accountNumber = static::getIndex(self::COLUMN_RELATED_ACCOUNT_NUMBER, $transactionArray, false);
        $this->accountBank = static::getIndex(self::COLUMN_RELATED_BANK_CODE, $transactionArray, false);
        $this->message = static::getIndex(self::COLUMN_MSG, $transactionArray, false);
        $this->vs = static::getIndex(self::COLUMN_VS, $transactionArray, false);
    }

    /**
     * Gets transactionArray index - optinonaly with array_key_exists test
     *
     * @param mixed $key
     * @param array $transactionArray
     * @param boolean $arrayKeyExists
     * @return mixed
     */
    private static function getIndex($key, array $transactionArray, $arrayKeyExists = true)
    {
        if (!$arrayKeyExists) {
            return $transactionArray[$key]['value'];
        }
        
        if (array_key_exists($key, $transactionArray)) {
            return $transactionArray[$key]['value'];
        } else {
            return false;
        }
    }
}
