<?php

namespace Countee\Model\Bank;

use Countee;
use Nette;

abstract class Transaction extends Nette\Object implements Countee\Model\Bank\ITransaction
{
    protected $id;
    protected $date;
    protected $ammount;
    protected $currency;
    protected $type;
    protected $accountNumber;
    protected $accountBank;
    protected $accountName;
    protected $message;
    protected $vs;

    /**
     * @var bool
     */
    protected $inputValid = false;

    /**
     * Constructtor
     * @param array $transactionArray
     * @return $this
     */
    public function __construct(array $transactionArray)
    {
        try {
            $this->inputValid = $this->validateInput($transactionArray);
        } catch (Countee\Model\Bank\Exception\InvalidStructure $ex) {
            $this->inputValid = false;
        }

        if ($this->inputValid) {
             $this->parseInput($transactionArray);
        }
       
        return $this;
    }

    /**
     * Validates transaction structure
     *
     * @param array $transactionArray
     * @return bool
    */
    abstract protected function validateInput(array $transactionArray);


    /**
     * Parse input string
     *
     * @param array $transactionArray
     */
    abstract protected function parseInput(array $transactionArray);

    public function inputValid()
    {
        return $this->inputValid;
    }

    public function getId()
    {
        return $this->id;
    }
    
    public function getAmmount()
    {
        return $this->ammount;
    }
    
    public function getAccountNumber()
    {
        return $this->accountNumber;
    }
    
    public function getAccountBank()
    {
        return $this->accountBank;
    }
    
    public function getVs()
    {
        return $this->vs;
    }

    public function getValues()
    {
        return [
            'bank_transaction_id' => $this->id,
            'date' => $this->date,
            'ammount' => $this->ammount,
            'currency' => $this->currency,
            'type' => $this->type,
            'related_account_number' => $this->accountNumber,
            'related_account_bank' => $this->accountBank,
            'related_account_name' => $this->accountName,
            'message' => $this->message,
            'vs' => $this->vs
        ];
    }
}
