<?php

namespace Countee\Model;

use Nette;

/**
 * Basic methods for DB manipulating
 */
abstract class BaseDatabaseModel
{

    /** @var Nette\Database\Context */
    protected $database;

    public function __construct(Nette\Database\Context $database)
    {
        $this->database = $database;
    }

    /**
     * Gets table
     * @param string $tableName
     */
    public function getTable($tableName)
    {
        return $this->database->table($tableName);
    }

    /**
     * Gets account from DB by ID of account
     *
     * @param int @accountId
     * @return mixed
     */
    public function getAccount(int $accountId, $userId = null)
    {
        $account = $this->database->table('account')->get($accountId);

        if (!$account) {
            throw new Bank\Exception\AccountDoesNotExistsException;
        }

        if (is_numeric($userId)) {
            if ($account->user_id != $userId) {
                throw new Bank\Exception\AccountDoesNotExistsException('Invalid User');
            }
        }
        
        return $account;
    }

    /**
     * Method gets bank row with given tag
     *
     * @param string $tag
     * @return \Nette\Database\Table\ActiveRow
     * @throws Bank\Exception\BankDoesNotExistsException
     */
    public function getBankByTag($tag)
    {
        $bank = $this->getTable('bank')->where('tag', $tag);
        if ($bank->count() == 0) {
            throw new Bank\Exception\BankDoesNotExistsException('Bank with tag ' . $tag . ' does not exists.');
        }

        return $bank->fetch();
    }
    
    
    /**
     * Gets user from DB by ID
     *
     * @param int @userId
     * @return Nette\Database\Table\IRow or FALSE if there is no such row
     */
    public function getUser(int $userId)
    {
        $user = $this->database->table('user')->get($userId);

        if (!$user) {
            throw new Exception\UserDoesNotExistsException;
        }
        
        return $user;
    }
    
    /**
     * Gets commitment from DB by ID
     *
     * @param int @userId
     * @return Nette\Database\Table\IRow or FALSE if there is no such row
     */
    public function getCommitment(int $commitmentId, $userId = null)
    {
        $commitment = $this->database->table('commitment')->get($commitmentId);
        
        if(!$commitment) {
            throw new \Nette\Application\BadRequestException;
        }
        
        if(!empty($userId)) {
            $user = $this->getUser($userId);
            
            if($commitment->user_id != $userId) {
                throw new Nette\Security\AuthenticationException;
            }
        }
        
        return $commitment;
    }
    
    /**
     * Gets receivable from DB by ID
     *
     * @param int @userId
     * @return Nette\Database\Table\IRow or FALSE if there is no such row
     */
    public function getReceivable(int $commitmentId, $userId = null)
    {
        $commitment = $this->database->table('receivable')->get($commitmentId);
        
        if(!$commitment) {
            throw new \Nette\Application\BadRequestException;
        }
        
        if(!empty($userId)) {
            $user = $this->getUser($userId);
            
            if($commitment->user_id != $userId) {
                throw new Nette\Security\AuthenticationException;
            }
        }
        
        return $commitment;
    }

}
