<?php

namespace Countee\Model\Category;

use Countee;
use GuzzleHttp;
use Nette;

class Assign extends Countee\Model\BaseDatabaseModel
{
    const MATCH_CRITERIA = 80;
    
    /**
     * 
     * @param int $userId
     * @param int $transactionId
     * @param int $categoryId
     * @param type $categoryUserAssigned
     * @return boolean
     * @throws \Nette\Security\AuthenticationException
     */
    
    public function assignCategory(int $userId, int $transactionId, int $categoryId, $categoryUserAssigned = true) {
        $user = $this->getUser($userId);
        $transaction = $this->getTable('transaction')->get($transactionId);
        $category = $this->getTable('category')->get($categoryId);

        if(!$transaction || !$category) {
            return false;
        }
        
        if($transaction->account->user_id != $userId || $category->user_id != $userId) {
            throw new \Nette\Security\AuthenticationException;
        }
        
        $transaction->update([
            'category_id' => $category->id,
            'category_user_assigned' => $categoryUserAssigned
        ]);
        
        if($categoryUserAssigned) {
            $this->estimateCategories($userId);
        }
    }
    
    public function estimateCategories(int $userId)
    {
        $user = $this->getUser($userId);
        
        $unAssignedTransactions = $this->getTable('transaction')->where([
            'category_user_assigned' => 0,
            'account.user_id' => $userId
        ]);
        
        foreach ($unAssignedTransactions as $transaction) {
            $categoryId = $this->getMatchCategoryId($transaction);
           
            if(is_numeric($categoryId)) {
                $this->assignCategory($userId, $transaction->id, $categoryId, false);
            }
        }
    }
    
    private function getMatchCategoryId(Nette\Database\Table\IRow $transaction)
    {
        
        $bankAccountMatch = false;
        $messageMatch = false;
        
        if (!empty($transaction->related_account_number) && !empty($transaction->related_account_bank)) {
            $tSameBankAccount = $this->getTable('transaction')->where([
                'related_account_number' => $transaction->related_account_number,
                'related_account_bank' => $transaction->related_account_bank,
                'account.user_id' => $transaction->account->user_id,
                'category_user_assigned' => 1,
            ]);
            
           if ($tSameBankAccount->count() > 0) {
               $bankAccountMatch = $tSameBankAccount->fetchPairs('id', 'id');
           }
        }
        
        if (!empty($transaction->message)) {
            $tMessage = $this->getTable('transaction')->where([
                'account.user_id' => $transaction->account->user_id,
                'category_user_assigned' => 1,
            ]);
            
            $tMessageArray = [];
            
            foreach ($tMessage as $message) {
                similar_text($transaction->message, $message->message, $matchPercent);
                if ($matchPercent > self::MATCH_CRITERIA) {
                    $tMessageArray[$message->id] = $matchPercent;
                }
            }
            
            if(!empty($tMessageArray)) {
                $messageMatch = $tMessageArray;
                arsort($messageMatch);
            }
        }
        
        if ($messageMatch && $bankAccountMatch) {
            foreach ($messageMatch as $key => $value) {
                if (in_array($key, $bankAccountMatch)) {
                    return $this->getTable('transaction')->get($key)->category_id;
                }
            }
        }
        
        if ($bankAccountMatch) {
            reset($bankAccountMatch);
            return $this->getTable('transaction')->get(key($bankAccountMatch))->category_id;
        }
        
        if ($messageMatch) {
            reset($messageMatch);
            return $this->getTable('transaction')->get(key($messageMatch))->category_id;
        }
        
    }
    
}
