<?php

namespace Countee\Model\Category;

use Countee;
use GuzzleHttp;
use Nette;

class Model extends Countee\Model\BaseDatabaseModel
{
    /**
     * @var Nette\DI\Container
     */
    private $container;
    
    public function __construct(Nette\Database\Context $database, Nette\DI\Container $container) {
        parent::__construct($database);
        
        $this->container = $container;
    }
    
    /**
     * Gets user categories
     * 
     * @param int $userId
     * @return array
     */
    public function getCategoriesForm($userId) {
        
        $cache = new Nette\Caching\Cache($this->container->getService('cacheStorage'), 'Categories');
        $categoryArray = $cache->load($userId);

        if($categoryArray === null) {
            $categoryArray = $this->generateCategoriesArray($userId);
            $cache->save($userId, $categoryArray);
        }
        
        return $categoryArray;
    }
    
    private function generateCategoriesArray($userId, $parentId = null) {
        $categories = $this->getTable('category')->where([
            'user_id' => $userId,
            'parent_id' => $parentId
        ]);
        
        $categoryArray = [];
        
        foreach($categories as $category) {
            $childCategories = $category->related('category');
            
            if($childCategories->count() > 0) {
                $categoryArray[$category->name] = $this->generateCategoriesArray($userId, $category->id);
            } else {
                $categoryArray[$category->id] = $category->name;
            }
        }
        
        return $categoryArray;
    }    
}
