<?php

namespace Countee\Model\Frontend;

use Countee;
use GuzzleHttp;
use Nette;

class Dashboard extends Countee\Model\BaseDatabaseModel
{

    /**
     * Get Asside Accounts info
     * @param int $userId
     * @return mixed
     */
    public function getAsideAccounts(int $userId)
    {
        $banksArray = [];
        $banks = $this->getTable('bank')->where(':account.user_id = ?', $userId);

        if ($banks->count() == 0) {
            return [];
        }

        foreach ($banks as $bank) {
            $bankArray = $bank->toArray();
            
            $accountsArray = [];
            foreach ($bank->related('account')->where(['user_id' => $userId])->order('account_name') as $account) {
                $accountsArray[] = $account->toArray();
            }
            
            $bankArray['accounts'] = $accountsArray;
            $banksArray[] = $bankArray;
        }
        
        return $banksArray;
    }

    public function getBalance(int $userId, $accountId)
    {
        if (empty($accountId)) {
            $sum = 0;
            
            foreach ($this->getUser($userId)->related('account') as $account) {
                $accountSum = $account->related('transaction')->select("SUM(ammount) AS suma")->fetch();
                $accountSum['suma'];
               
                $sum += (float)$accountSum['suma'];
            }
            
            return $sum;
        }
        
        $account = $this->getTable('account')->get($accountId);
        
        if ($account) {
            if($account->user_id == $userId) {
                $accountSum = $account->related('transaction')->select("SUM(ammount) AS suma")->fetch();
                return $accountSum['suma'];
            }
        }
        
        return false;
    }
    
    public function getTransactions(int $userId, $accountId) {
        $transactions = $this->getTable('transaction')->where('account.user_id = ?', $userId);
        
        if(is_numeric($accountId)) {
            $transactions->where('account.id = ?', $accountId);
        }
        
        return $transactions->order('date DESC');
    } 
    
    /**
     * Gets active account info
     * 
     * @param int $userId
     * @param type $accountId
     * @return mixed
     */
    public function getActiveAccountInfo(int $userId, $accountId)
    {
        $account = $this->getTable('account')->get($accountId);
        
        if ($account) {
            if($account->user_id == $userId) {
                return $account;
            }
        }
        
        return false;
    }

}
