<?php

namespace Countee\Model\Invoice;

use Countee;
use GuzzleHttp;
use Nette;
use Nette\Utils\Image;

class Parse
{

    /**
     * @var string
     */
    private $fileLocation;

    public function __construct($fileLocation)
    {
        if (!file_exists($fileLocation)) {
            throw new Exception\InputFileDoesNotExistsException;
        }

        $this->fileLocation = $fileLocation;
    }

    public function getSpayd()
    {
        //Convert file to JPG
        $jpgPath = $this->convertJpg($this->fileLocation);

        // Get divided images paths
        $dividedImages = $this->divide($jpgPath);

        $spayd = null;

        foreach ($dividedImages as $dividedImage) {
            $qrcode = new \QrReader($dividedImage);
            $text = $qrcode->text();

            if (!empty($text)) {
                $spayd = $text;
                break;
            }
        }

        // Cleanup
        unlink($this->fileLocation);
        unlink($jpgPath);

        foreach ($dividedImages as $dividedImage) {
            unlink($dividedImage);
        }

        return iconv("UTF-8","ISO-8859-1//IGNORE", $spayd);
    }

    private function convertJpg($fileLocation)
    {
        $jpgPath = $fileLocation . '.jpg';

        exec("/bin/bash -lc 'convert -density 200 -trim " . $fileLocation . " -quality 100 " . $jpgPath . "'");
        if (!file_exists($fileLocation . ".jpg")) {
            throw new Exception\InvoiceProcessErrorException('Nezdařil se převod PDF');
        }

        $image = Image::fromFile($jpgPath);

        //rotate if horizontal
        if ($image->width > $image->height) {
            $image->rotate(90, 0);
            $image->save($jpgPath);
        }

        return $jpgPath;
    }

    private function divide($jpgPath)
    {
        $path = pathinfo($jpgPath);

        $dividedImages = [
            $path['dirname'] . '/' . $path['filename'] . '_0.jpg',
            $path['dirname'] . '/' . $path['filename'] . '_1.jpg',
            $path['dirname'] . '/' . $path['filename'] . '_2.jpg',
            $path['dirname'] . '/' . $path['filename'] . '_3.jpg',
            $path['dirname'] . '/' . $path['filename'] . '_4.jpg',
            $path['dirname'] . '/' . $path['filename'] . '_5.jpg',
        ];

        //Left Top
        $image = Image::fromFile($jpgPath);
        $image->crop(0, 0, $image->width / 2, $image->height / 2);
        $image->save($dividedImages[0]);

        //Right Top
        $image = Image::fromFile($jpgPath);
        $image->crop($image->width / 2, 0, $image->width / 2, $image->height / 2);
        $image->save($dividedImages[1]);

        //Left Middle
        $image = Image::fromFile($jpgPath);
        $image->crop(0, $image->height * 0.25, $image->width / 2, $image->height * 0.75);
        $image->save($dividedImages[2]);

        //Right Middle
        $image = Image::fromFile($jpgPath);
        $image->crop($image->width / 2, $image->height * 0.25, $image->width / 2, $image->height * 0.75);
        $image->save($dividedImages[3]);

        //Left Bottom
        $image = Image::fromFile($jpgPath);
        $image->crop(0, $image->height / 2, $image->width / 2, $image->height / 2);
        $image->save($dividedImages[4]);

        //Right Bottom
        $image = Image::fromFile($jpgPath);
        $image->crop($image->width / 2, $image->height / 2, $image->width / 2, $image->height / 2);
        $image->save($dividedImages[5]);


        return $dividedImages;
    }

}
