<?php

namespace Countee\Model\Payable;

use Higi90\SpaydParser;
use Countee;

class Receivable extends Base
{
    
    const STATUS_CREATED = 1;
    const STATUS_PAID = 2;


    /**
     * Creates receivable record
     * 
     * @param int $userId
     * @param type $values
     * @return type
     */
    public function createReceivable(int $userId, $values)
    {

        $user = $this->getUser($userId);

        if (!empty($values->account_id)) {
            $this->getAccount($values->account_id, $userId);
        }

        if($values->due_date) {
            if(!is_object($values->due_date) || !($values->due_date instanceof \Datetime)) {
                $dueDate = \DateTime::createFromFormat('d. m. Y', $values->due_date);
            } else {
                $dueDate = $values->due_date;
            }  
        } else {
            $dueDate = new \DateTime;
        }

        unset($values->due_date);

        $dbValues = array_merge([
            'user_id' => $user->id,
            'due_date' => $dueDate,
            'status' => self::STATUS_CREATED
                ], (array) $values);
        $receivable = $this->getTable('receivable')->insert($dbValues);

        return $receivable;
    }

    /**
     * Edits receivable record
     * 
     * @param int $userId
     * @param int $receivableId
     * @param type $values
     * @return type
     */
    public function editReceivable(int $userId, int $receivableId, $values)
    {
        $user = $this->getUser($userId);
        $receivable = $this->getReceivable($receivableId, $userId);

        if (!empty($values->account_id)) {
            $this->getAccount($values->account_id, $userId);
        }

        if ($receivable->paid > 0) {
            $receivable->update(['name' => $values->name, 'description' => $values->description]);
            return $receivable;
        }

        $dueDate = $date = \DateTime::createFromFormat('d. m. Y', $values->due_date);

        unset($values->due_date);

        $dbValues = array_merge([
            'user_id' => $user->id,
            'due_date' => $dueDate,
                ], (array) $values);

        $receivable->update($dbValues);

        return $receivable;
    }

    /**
     * Gets receivables selection
     * 
     * @param int $userId
     * @param type $accountId
     * @return type
     */
    public function getReceivables(int $userId, $accountId = null)
    {
        $user = $this->getUser($userId);
        $receivables = $user->related('receivable');

        if (!empty($accountId)) {
            $receivables = $receivables->where(['account_id' => $accountId]);
        }

        return $receivables;
    }
   
    /**
     * Deletes recievable
     * @param int $receivableId
     * @param int $userId
     * @return type
     */
    public function deleteReceivable(int $receivableId, int $userId)
    {
        $receivable = $this->getReceivable($receivableId, $userId);
        return $receivable->delete();
    }
    
    /**
     * 
     * @param int $accountId
     * @param type $vs
     */
    public function syncReceivable(int $accountId, $vs, $ammount)
    {
        $receivables = $this->getTable('receivable')->where([
            'account_id' => $accountId,
            'vs' => $vs,
            'status' => self::STATUS_CREATED
        ]);
        
        foreach ($receivables as $receivable) {
            if($receivable->ammount > $receivable->paid) {
                $paid = (float)$receivable->paid + (float)$ammount;
                
                if($paid >= (float)$receivable->ammount) {
                    $receivable->update([
                        'paid' => $paid,
                        'status' => self::STATUS_PAID
                    ]);
                } else {
                    $receivable->update([
                        'paid' => $paid,
                    ]);
                }
            }
        }
    }

}
