<?php

namespace Countee\Presenters;

use Nette;
use Nette\Application\UI\Multiplier;
use Nette\Utils\Paginator;
use Countee\Model;
use Countee;

class CommitmentPresenter extends SecuredPresenter
{

    /**
     * @var \Countee\Components\Payable\Factory
     * @inject
     */
    public $payableFactory;

    /**
     * @var \Countee\Model\Payable\Commitment
     * @inject
     */
    public $commitmentModel;

    protected function createComponentCommitmentAdd()
    {
        return $this->payableFactory->createCommitment($this->user->id);
    }

    protected function createComponentCommitmentSpaydAdd()
    {
        return $this->payableFactory->createCommitmentSpayd($this->user->id);
    }
    
    protected function createComponentCommitmentInvoiceAdd()
    {
        return $this->payableFactory->createCommitmentInvoice($this->user->id);
    }

    protected function createComponentCommitmentEdit()
    {
        return new Multiplier(function (int $commitmentId) {
            return $this->payableFactory->createCommitment($this->user->id, $commitmentId);
        });
    }

    public function handleDeleteCommitment(int $commitmentId)
    {
        $this->commitmentModel->deleteCommitment($commitmentId, $this->user->id);
        $this->flashMessage('Závazek byl odebrán', 'success');
    }
    
    public function handlePay(int $commitmentId)
    {
        try {
            $this->commitmentModel->pay($this->user->id, $commitmentId);
        } catch (Countee\Model\Bank\Exception\SyncLimitException $e ) {
            $this->flashMessage('Byl překročen limit požadavků. Zkuste to prosím později.', 'danger');
        } catch (Countee\Model\Bank\Exception\RequestLimitException $e ) {
            $this->flashMessage('Byl překročen limit požadavků. Zkuste to prosím později.', 'danger');
        } catch (Countee\Model\Bank\Exception\GeneralSyncException $e) {
            $this->flashMessage('Zadání platby se nezdařilo. Špatné přístupové údaje?', 'danger');
        }

        $this->redirect('this');
    }

    public function renderDefault($accountId = null, $page = 1)
    {
        //Pagination
        $transactions = $this->commitmentModel->getCommitments($this->user->id, $accountId);
        $paginator = new Nette\Utils\Paginator;
        $paginator->setItemCount($transactions->count());
        $paginator->setItemsPerPage(20);
        $paginator->setPage($page);

        $this->template->paginator = $paginator;
        $this->template->paginatorShowFirst = Countee\Helper\Paginator::getFirst($paginator);
        $this->template->paginatorShowLast = Countee\Helper\Paginator::getLast($paginator);

        $this->template->transactions = $transactions->order('due_date DESC')->limit($paginator->getLength(), $paginator->getOffset());
        $this->template->accountInfo = $this->frontendDashboard->getActiveAccountInfo($this->user->id, $accountId);
    }
}
