<?php

namespace Countee\Presenters;

use Nette;
use Nette\Application\UI\Multiplier;
use Nette\Utils\Paginator;
use Countee\Model;
use Countee;

class ReceivablePresenter extends SecuredPresenter
{
 
    /**
     * @var \Countee\Components\Payable\Factory
     * @inject
     */
    public $payableFactory;

    /**
     * @var \Countee\Model\Payable\Receivable
     * @inject
     */
    public $receivableModel;

    protected function createComponentReceivableAdd()
    {
        return $this->payableFactory->createReceivable($this->user->id);
    }

    protected function createComponentReceivableEdit()
    {
        return new Multiplier(function (int $receivableId) {
            return $this->payableFactory->createReceivable($this->user->id, $receivableId);
        });
    }

    public function handlePay(int $receivableId)
    {
        try {
            $this->receivableModel->pay($this->user->id, $receivableId);
        } catch (Countee\Model\Bank\Exception\SyncLimitException $e ) {
            $this->flashMessage('Byl překročen limit požadavků. Zkuste to prosím později.', 'danger');
        } catch (Countee\Model\Bank\Exception\RequestLimitException $e ) {
            $this->flashMessage('Byl překročen limit požadavků. Zkuste to prosím později.', 'danger');
        } catch (Countee\Model\Bank\Exception\GeneralSyncException $e) {
            $this->flashMessage('Zadání platby se nezdařilo. Špatné přístupové údaje?', 'danger');
        }

        $this->redirect('this');
    }
    
    public function handleDeleteReceivable(int $receivableId)
    {
        $this->receivableModel->deleteReceivable($receivableId, $this->user->id);
        $this->flashMessage('Závazek byl odebrán', 'success');
    }

    public function renderDefault($accountId = null, $page = 1)
    {
        //Pagination
        $transactions = $this->receivableModel->getReceivables($this->user->id, $accountId);
        $paginator = new Nette\Utils\Paginator;
        $paginator->setItemCount($transactions->count());
        $paginator->setItemsPerPage(20);
        $paginator->setPage($page);

        $this->template->paginator = $paginator;
        $this->template->paginatorShowFirst = Countee\Helper\Paginator::getFirst($paginator);
        $this->template->paginatorShowLast = Countee\Helper\Paginator::getLast($paginator);

        $this->template->transactions = $transactions->order('due_date DESC')->limit($paginator->getLength(), $paginator->getOffset());
        $this->template->accountInfo = $this->frontendDashboard->getActiveAccountInfo($this->user->id, $accountId);
    }
}
