<?php

namespace Countee\Presenters;

use Nette;
use Nette\Utils\Paginator;
use Nette\Application\UI\Multiplier;
use Countee\Model;
use Countee;

abstract class SecuredPresenter extends BasePresenter {

    public function startup() {
        parent::startup();

        if (!$this->user->isLoggedIn()) {
            $this->flashMessage('Pro vstup na tyto stránky je nutné přihlášení.', 'error');
            $this->redirect('Sign:');
            die('Unauthorized');
        }
    }

    /**
     * @var \Countee\Model\Bank\Fio\Account
     * @inject
     */
    public $fioAccount;

    /**
     * @var \Countee\Model\Category\Assign
     * @inject
     */
    public $categoryAssign;

    /**
     * @var \Countee\Components\Account\Factory
     * @inject
     */
    public $accountComponentFactory;

    /**
     * @var \Countee\Components\Category\Factory
     * @inject
     */
    public $categoryComponentFactory;

    /**
     * @var \Countee\Model\Bank\AccountFactory
     * @inject
     */
    public $accountFactory;

    /**
     * @var \Countee\Model\Frontend\Dashboard 
     * @inject
     */
    public $frontendDashboard;

    /**
     * @var \Countee\Model\Email\Read
     * @inject
     */
    public $readEmail;

    protected function createComponentAccountAdd() {
        return new Multiplier(function ($bankToken) {
            return $this->accountComponentFactory->createAccount($this->user->id, $bankToken);
        });
    }

    protected function createComponentAccountEdit() {
        return new Multiplier(function ($bankToken) {
            return $this->accountComponentFactory->editAccount($this->user->id, $this->getParameter('accountId'));
        });
    }

    public function handleSyncAccount(int $accountId) {
        $accountObj = $this->accountFactory->getAccountObject($accountId, $this->user->id);

        if ($accountObj) {
            try {
                $accountObj->syncAccount($accountId);
                $this->flashMessage('Účet ' . $accountObj->getAccount($accountId)->account_name . ' byl synchronizován.', 'success');
            } catch (\Countee\Model\Bank\Exception\SyncLimitException $e) {
                $this->flashMessage('Byl překročen limit požadavků. Zkuste to prosím později.', 'danger');
            } catch (\Countee\Model\Bank\Exception\GeneralSyncException $e) {
                $this->flashMessage('Synchronizace účtu ' . $accountObj->getAccountName($accountId, $this->user->id) . ' se nezdařila. Špatné přístupové údaje?', 'danger');
            }
        } else {
            $this->flashMessage('Něco se pokazilo. Zkuste to prosím později.', 'danger');
        }
        
        $this->redirect('this');
    }
    
    public function beforeRender()
    {
        parent::beforeRender();
        $accountId = !empty($this->request->getParameters()['accountId'])?$this->request->getParameters()['accountId']:null;
        $this->template->balance = $this->frontendDashboard->getBalance($this->user->id, $accountId);

// Aside accounts 
        $this->template->asideAccounts = $this->frontendDashboard->getAsideAccounts($this->user->id);
    }

}
