<?php

namespace Countee\Presenters;

use Nette;
use Countee\Forms;
use Countee\Model;

class SignPresenter extends BasePresenter
{

    /** @var \Kdyby\Facebook\Facebook */
    private $facebook;

    /** @var UsersModel */
    private $userManager;

    /**
     * You can use whatever way to inject the instance from DI Container,
     * but let's just use constructor injection for simplicity.
     *
     * Class UsersModel is here only to show you how the process should work,
     * you have to implement it yourself.
     */
    public function __construct(\Kdyby\Facebook\Facebook $facebook, Model\UserManager $userManager)
    {
        parent::__construct();
        $this->facebook = $facebook;
        $this->userManager = $userManager;
    }


    /** @return \Kdyby\Facebook\Dialog\LoginDialog */
    protected function createComponentFbLogin()
    {
        $dialog = $this->facebook->createDialog('login');
        /** @var \Kdyby\Facebook\Dialog\LoginDialog $dialog */

        $dialog->onResponse[] = function (\Kdyby\Facebook\Dialog\LoginDialog $dialog) {
            $fb = $dialog->getFacebook();

            if (!$fb->getUser()) {
                $this->flashMessage("Sorry bro, facebook authentication failed.");
                return;
            }

            try {
                $me = $fb->api('/me?fields=id,name,email,picture');
                $existing = $this->userManager->findByFacebookId($fb->getUser());
                        
                if (!$existing) {
                    $existing = $this->userManager->registerFromFacebook($me);
                }

                $this->userManager->updateFacebookAccessToken($fb->getUser(), $fb->getAccessToken());


                $this->user->login(new \Nette\Security\Identity($existing->id, null, $existing));

                /**
                 * User authenticated. Redirect ... Homepage
                 */
                
                $this->redirect('Transaction:');
            } catch (\Kdyby\Facebook\FacebookApiException $e) {
                \Tracy\Debugger::log($e, 'facebook');
                $this->flashMessage("Sorry bro, facebook authentication failed hard.");
                $this->redirect('this');
            }
        };

        return $dialog;
    }
    
    public function actionOut()
    {
        $this->user->logout();
        $this->redirect('Sign:');
    }
}
