module.exports = function(grunt) {

  grunt.initConfig({
    pkg:grunt.file.readJSON('package.json'),
    less: {
      compile: {
        files: {
          '../www/assets/css/style.css' : 'less/style.less',
        }
      }
    },
    cssmin: {
      options: {
        shorthandCompacting: false,
        roundingPrecision: -1,
        processImport: false
      },
      target: {
        files: {
          '../www/assets/css/style.min.css': ['../www/assets/css/style.css'],
        }
      }
    },
    concat: {
      dist_css: {
        src: [
          'bower_components/eonasdan-bootstrap-datetimepicker/build/css/bootstrap-datetimepicker.min.css',
          '../www/assets/css/style.css',
          'bower_components/components-font-awesome/css/font-awesome.css',
        ],
        dest: '../www/assets/css/style.css'
      },
      dist_js: {
        src: [
          'bower_components/jquery/dist/jquery.min.js',
          'bower_components/moment/moment.js',
          'bower_components/moment/locale/cs.js',
          'bower_components/typed.js/dist/typed.min.js',
          'bower_components/smoothscroll-for-websites/smoothscroll.js',
          'bower_components/bootstrap/dist/js/bootstrap.min.js',
          'bower_components/nette.ajax.js/nette.ajax.js',
          'bower_components/eonasdan-bootstrap-datetimepicker/build/js/bootstrap-datetimepicker.min.js',
          'js/libary/*.js',
          'js/script/*.js'
        ],
        dest: '../www/assets/js/javascript.js'
      },
    },
    uglify: {
      target: {
        files: {
          '../www/assets/js/javascript.min.js': ['../www/assets/js/javascript.js']
        }
      }
    },
    bowercopy: {
      scripts: {
        files: {
          '../www/assets/js/selectivizr.js': 'selectivizr/selectivizr.js',
          '../www/assets/js/html5shiv.min.js': 'html5shiv/dist/html5shiv.min.js',
          '../www/assets/fonts': ['components-font-awesome/fonts/*', 'bootstrap/fonts/*']
        }
      }
    },
    svg_sprite: {
      target: {
        src			: ['svg/*.svg'],
        dest		: '../www/assets/',
        options				: {
          mode			: {
            css			: {
              render	: {
                css	: true
              }
            }
          }
        }
      },
    },
    watch:{
      less: {
        files: ['less/**/*.less'],
        tasks: ['less', 'concat', 'cssmin']
      },
      uglify: {
        files: ['js/**/*.js'],
        tasks: ['concat', 'uglify']
      }
    }
  });

  grunt.loadNpmTasks('grunt-contrib-less');
  grunt.loadNpmTasks('grunt-contrib-watch');
  grunt.loadNpmTasks('grunt-contrib-cssmin');
  grunt.loadNpmTasks('grunt-contrib-concat');
  grunt.loadNpmTasks('grunt-contrib-uglify');
  grunt.loadNpmTasks('grunt-bowercopy');
  grunt.loadNpmTasks('grunt-svg-sprite');


  grunt.registerTask('default', ['svg_sprite', 'less', 'concat', 'cssmin', 'uglify']);
  grunt.registerTask('bower-update', ['bowercopy']);

};